@@ -14,6 +14,7 @@ from rvbd.shark._interfaces import loaded
 from rvbd.shark._exceptions import SharkException
 from rvbd.common import utils, timeutils
 
+
 class Interface4(_interfaces._InputSource):
     """A physical interface packet source, that can be used for live packet
     capture. Interface objects are normally not instantianted directly, but
@@ -75,12 +76,6 @@ class Clip4(_interfaces.Clip):
     def _load(self):
         self.data = self.shark.api.clips.get_details(self.id)
 
-
-    # XXX version 3 clip has stuff this doesn't have:
-    #  - timerange property
-    #  - export() method
-    #  - get_job() method
-
     @property
     def source_path(self):
         """Return the path of a Clip used for the internal shark representation
@@ -155,7 +150,14 @@ class Clip4(_interfaces.Clip):
         """
         pass
 
-class Job4(_interfaces._InputSource):
+    def download(self, path=None):
+        """Download the Clip packets to a file.
+        If path is None packets will be exported to a temporary file.
+        A file object that contains the packets is returned.
+        """
+        return open(self.shark.api.clips.get_packets(self.id, path), 'rb')
+
+class Job4(_interfaces.Job):
     """A capture job packet source. These objects are normally not
     instantiated directly, but are instead obtained by calling
     `Shark.get_capture_jobs` or `Shark.get_capture_job_by_name`.
@@ -302,7 +304,7 @@ class Job4(_interfaces._InputSource):
         if requested_stop_time:
             requested_stop_time = requested_stop_time.strftime(cls._timefmt)
 
-        jobrequest = { 'interface_name': str(interface) }
+        jobrequest = { 'interface_name': interface.id }
 
         if name:
             jobrequest['name'] = name
@@ -394,11 +396,13 @@ class Job4(_interfaces._InputSource):
         """
         return Clip4.add(self.shark, self, filters, description, locked)
 
-    def export(self, filename, filters=None):
-        """Export the CaptureJob packets selected by filters to a file
+    def download(self, path=None):
+        """Download the Job packets to a path.
+        If path is None packets will be exported to a temporary file.
+        A file object that contains the packets is returned.
         """
-        raise UnimplementedEror()
-
+        return open(self.shark.api.jobs.get_packets(self.id, path), 'rb')
+        
     def get_state(self):
         """Return the state of the job (e.g. RUNNING, STOPPED)"""
         return self.get_status().state
